@@ -1,3 +1,6 @@
+// SPDX-FileCopyrightText: 2023 The Pion community <https://pion.ly>
+// SPDX-License-Identifier: MIT
+
 //go:build !debug
 // +build !debug
 
@@ -6,7 +9,7 @@ package stun
 import (
 	"errors"
 
-	"github.com/pion/stun/internal/hmac"
+	"github.com/pion/stun/v3/internal/hmac"
 )
 
 // CheckSize returns ErrAttrSizeInvalid if got is not equal to expected.
@@ -14,6 +17,7 @@ func CheckSize(_ AttrType, got, expected int) error {
 	if got == expected {
 		return nil
 	}
+
 	return ErrAttributeSizeInvalid
 }
 
@@ -21,6 +25,7 @@ func checkHMAC(got, expected []byte) error {
 	if hmac.Equal(got, expected) {
 		return nil
 	}
+
 	return ErrIntegrityMismatch
 }
 
@@ -28,6 +33,7 @@ func checkFingerprint(got, expected uint32) error {
 	if got == expected {
 		return nil
 	}
+
 	return ErrFingerprintMismatch
 }
 
@@ -37,10 +43,11 @@ func IsAttrSizeInvalid(err error) bool {
 }
 
 // CheckOverflow returns ErrAttributeSizeOverflow if got is bigger that max.
-func CheckOverflow(_ AttrType, got, max int) error {
-	if got <= max {
+func CheckOverflow(_ AttrType, got, maxVal int) error {
+	if got <= maxVal {
 		return nil
 	}
+
 	return ErrAttributeSizeOverflow
 }
 
