@@ -1,17 +1,18 @@
-// Copyright 2009 The Go Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style
-// license that can be found in the LICENSE file.
+// SPDX-FileCopyrightText: 2009 The Go Authors. All rights reserved.
+// SPDX-License-Identifier: BSD-3-Clause
 
 package hmac
 
-import ( // nolint:gci
-	"crypto/md5"  // nolint:gosec
-	"crypto/sha1" // nolint:gosec
+import (
+	"crypto/md5"  //nolint:gosec
+	"crypto/sha1" //nolint:gosec
 	"crypto/sha256"
 	"crypto/sha512"
 	"fmt"
 	"hash"
 	"testing"
+
+	"github.com/stretchr/testify/assert"
 )
 
 type hmacTest struct {
@@ -23,7 +24,7 @@ type hmacTest struct {
 	blocksize int
 }
 
-func hmacTests() []hmacTest {
+func hmacTests() []hmacTest { //nolint:maintidx
 	return []hmacTest{
 		// Tests from US FIPS 198
 		// https://csrc.nist.gov/publications/fips/fips198/fips-198a.pdf
@@ -405,7 +406,7 @@ func hmacTests() []hmacTest {
 		},
 		{
 			sha512.New384,
-			[]byte{ // nolint:dupl
+			[]byte{ //nolint:dupl
 				0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
 				0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
 				0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17,
@@ -485,7 +486,7 @@ func hmacTests() []hmacTest {
 		},
 		{
 			sha512.New,
-			[]byte{ // nolint:dupl
+			[]byte{ //nolint:dupl
 				0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07,
 				0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
 				0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17,
@@ -524,41 +525,33 @@ func hmacTests() []hmacTest {
 
 func TestHMAC(t *testing.T) {
 	for i, tt := range hmacTests() {
-		h := New(tt.hash, tt.key)
-		if s := h.Size(); s != tt.size {
-			t.Errorf("Size: got %v, want %v", s, tt.size)
-		}
-		if b := h.BlockSize(); b != tt.blocksize {
-			t.Errorf("BlockSize: got %v, want %v", b, tt.blocksize)
-		}
-		for j := 0; j < 4; j++ {
-			n, err := h.Write(tt.in)
-			if n != len(tt.in) || err != nil {
-				t.Errorf("test %d.%d: Write(%d) = %d, %v", i, j, len(tt.in), n, err)
-				continue
-			}
+		hsh := New(tt.hash, tt.key)
+		assert.Equal(t, tt.size, hsh.Size(), "Size mismatch")
+		assert.Equal(t, tt.blocksize, hsh.BlockSize(), "BlockSize mismatch")
+		for j := 0; j < 4; j++ { //nolint:varnamelen
+			n, err := hsh.Write(tt.in)
+			assert.Equal(t, len(tt.in), n, "test %d.%d: Write(%d) = %d", i, j, len(tt.in), n)
+			assert.NoError(t, err, "test %d.%d: Write error", i, j)
 
 			// Repetitive Sum() calls should return the same value
 			for k := 0; k < 2; k++ {
-				sum := fmt.Sprintf("%x", h.Sum(nil))
-				if sum != tt.out {
-					t.Errorf("test %d.%d.%d: have %s want %s", i, j, k, sum, tt.out)
-				}
+				sum := fmt.Sprintf("%x", hsh.Sum(nil))
+				assert.Equal(t, tt.out, sum, "test %d.%d.%d: have %s want %s", i, j, k, sum, tt.out)
 			}
 
 			// Second iteration: make sure reset works.
-			h.Reset()
+			hsh.Reset()
 
 			// Third and fourth iteration: make sure hmac works on
 			// hashes without MarshalBinary/UnmarshalBinary
 			if j == 1 {
-				h = New(func() hash.Hash { return justHash{tt.hash()} }, tt.key)
+				hsh = New(func() hash.Hash { return justHash{tt.hash()} }, tt.key)
 			}
 		}
 	}
 }
 
-// justHash implements just the hash.Hash methods and nothing else
+// justHash implements just the hash.Hash methods and nothing else.
 type justHash struct {
 	hash.Hash
 }
@@ -568,18 +561,10 @@ func TestEqual(t *testing.T) {
 	b := []byte("test1")
 	c := []byte("test2")
 
-	if !Equal(b, b) {
-		t.Error("Equal failed with equal arguments")
-	}
-	if Equal(a, b) {
-		t.Error("Equal accepted a prefix of the second argument")
-	}
-	if Equal(b, a) {
-		t.Error("Equal accepted a prefix of the first argument")
-	}
-	if Equal(b, c) {
-		t.Error("Equal accepted unequal slices")
-	}
+	assert.True(t, Equal(b, b), "Equal failed with equal arguments")
+	assert.False(t, Equal(a, b), "Equal accepted a prefix of the second argument")
+	assert.False(t, Equal(b, a), "Equal accepted a prefix of the first argument")
+	assert.False(t, Equal(b, c), "Equal accepted unequal slices")
 }
 
 func BenchmarkHMACSHA256_1K(b *testing.B) {
@@ -588,7 +573,7 @@ func BenchmarkHMACSHA256_1K(b *testing.B) {
 	h := New(sha256.New, key)
 	b.SetBytes(int64(len(buf)))
 	for i := 0; i < b.N; i++ {
-		h.Write(buf) // nolint:errcheck,gosec
+		h.Write(buf) //nolint:errcheck,gosec
 		h.Reset()
 		mac := h.Sum(nil)
 		buf[0] = mac[0]
@@ -601,7 +586,7 @@ func BenchmarkHMACSHA256_32(b *testing.B) {
 	h := New(sha256.New, key)
 	b.SetBytes(int64(len(buf)))
 	for i := 0; i < b.N; i++ {
-		h.Write(buf) // nolint:errcheck,gosec
+		h.Write(buf) //nolint:errcheck,gosec
 		h.Reset()
 		mac := h.Sum(nil)
 		buf[0] = mac[0]
