@@ -3,11 +3,13 @@
 
 package hmac
 
-import ( //nolint:gci
+import (
 	"crypto/sha1" //nolint:gosec
 	"crypto/sha256"
 	"fmt"
 	"testing"
+
+	"github.com/stretchr/testify/assert"
 )
 
 func BenchmarkHMACSHA1_512(b *testing.B) {
@@ -42,100 +44,76 @@ func BenchmarkHMACSHA1_512_Pool(b *testing.B) {
 
 func TestHMACReset(t *testing.T) {
 	for i, tt := range hmacTests() {
-		h := New(tt.hash, tt.key)
-		h.(*hmac).resetTo(tt.key) //nolint:forcetypeassert
-		if s := h.Size(); s != tt.size {
-			t.Errorf("Size: got %v, want %v", s, tt.size)
-		}
-		if b := h.BlockSize(); b != tt.blocksize {
-			t.Errorf("BlockSize: got %v, want %v", b, tt.blocksize)
-		}
+		hsh := New(tt.hash, tt.key)
+		hsh.(*hmac).resetTo(tt.key) //nolint:forcetypeassert
+		assert.Equal(t, tt.size, hsh.Size(), "Size mismatch")
+		assert.Equal(t, tt.blocksize, hsh.BlockSize(), "BlockSize mismatch")
 		for j := 0; j < 2; j++ {
-			n, err := h.Write(tt.in)
-			if n != len(tt.in) || err != nil {
-				t.Errorf("test %d.%d: Write(%d) = %d, %v", i, j, len(tt.in), n, err)
-				continue
-			}
+			n, err := hsh.Write(tt.in)
+			assert.Equal(t, len(tt.in), n, "test %d.%d: Write(%d) = %d", i, j, len(tt.in), n)
+			assert.NoError(t, err, "test %d.%d: Write error", i, j)
 
 			// Repetitive Sum() calls should return the same value
 			for k := 0; k < 2; k++ {
-				sum := fmt.Sprintf("%x", h.Sum(nil))
-				if sum != tt.out {
-					t.Errorf("test %d.%d.%d: have %s want %s", i, j, k, sum, tt.out)
-				}
+				sum := fmt.Sprintf("%x", hsh.Sum(nil))
+				assert.Equal(t, tt.out, sum, "test %d.%d.%d: have %s want %s", i, j, k, sum, tt.out)
 			}
 
 			// Second iteration: make sure reset works.
-			h.Reset()
+			hsh.Reset()
 		}
 	}
 }
 
-func TestHMACPool_SHA1(t *testing.T) { //nolint:dupl
+func TestHMACPool_SHA1(t *testing.T) { //nolint:dupl,cyclop
 	for i, tt := range hmacTests() {
 		if tt.blocksize != sha1.BlockSize || tt.size != sha1.Size {
 			continue
 		}
-		h := AcquireSHA1(tt.key)
-		if s := h.Size(); s != tt.size {
-			t.Errorf("Size: got %v, want %v", s, tt.size)
-		}
-		if b := h.BlockSize(); b != tt.blocksize {
-			t.Errorf("BlockSize: got %v, want %v", b, tt.blocksize)
-		}
+		hsh := AcquireSHA1(tt.key)
+		assert.Equal(t, tt.size, hsh.Size(), "Size mismatch")
+		assert.Equal(t, tt.blocksize, hsh.BlockSize(), "BlockSize mismatch")
 		for j := 0; j < 2; j++ {
-			n, err := h.Write(tt.in)
-			if n != len(tt.in) || err != nil {
-				t.Errorf("test %d.%d: Write(%d) = %d, %v", i, j, len(tt.in), n, err)
-				continue
-			}
+			n, err := hsh.Write(tt.in)
+			assert.Equal(t, len(tt.in), n, "test %d.%d: Write(%d) = %d", i, j, len(tt.in), n)
+			assert.NoError(t, err, "test %d.%d: Write error", i, j)
 
 			// Repetitive Sum() calls should return the same value
 			for k := 0; k < 2; k++ {
-				sum := fmt.Sprintf("%x", h.Sum(nil))
-				if sum != tt.out {
-					t.Errorf("test %d.%d.%d: have %s want %s", i, j, k, sum, tt.out)
-				}
+				sum := fmt.Sprintf("%x", hsh.Sum(nil))
+				assert.Equal(t, tt.out, sum, "test %d.%d.%d: have %s want %s", i, j, k, sum, tt.out)
 			}
 
 			// Second iteration: make sure reset works.
-			h.Reset()
+			hsh.Reset()
 		}
-		PutSHA1(h)
+		PutSHA1(hsh)
 	}
 }
 
-func TestHMACPool_SHA256(t *testing.T) { //nolint:dupl
+func TestHMACPool_SHA256(t *testing.T) { //nolint:dupl,cyclop
 	for i, tt := range hmacTests() {
 		if tt.blocksize != sha256.BlockSize || tt.size != sha256.Size {
 			continue
 		}
-		h := AcquireSHA256(tt.key)
-		if s := h.Size(); s != tt.size {
-			t.Errorf("Size: got %v, want %v", s, tt.size)
-		}
-		if b := h.BlockSize(); b != tt.blocksize {
-			t.Errorf("BlockSize: got %v, want %v", b, tt.blocksize)
-		}
+		hsh := AcquireSHA256(tt.key)
+		assert.Equal(t, tt.size, hsh.Size(), "Size mismatch")
+		assert.Equal(t, tt.blocksize, hsh.BlockSize(), "BlockSize mismatch")
 		for j := 0; j < 2; j++ {
-			n, err := h.Write(tt.in)
-			if n != len(tt.in) || err != nil {
-				t.Errorf("test %d.%d: Write(%d) = %d, %v", i, j, len(tt.in), n, err)
-				continue
-			}
+			n, err := hsh.Write(tt.in)
+			assert.Equal(t, len(tt.in), n, "test %d.%d: Write(%d) = %d", i, j, len(tt.in), n)
+			assert.NoError(t, err, "test %d.%d: Write error", i, j)
 
 			// Repetitive Sum() calls should return the same value
 			for k := 0; k < 2; k++ {
-				sum := fmt.Sprintf("%x", h.Sum(nil))
-				if sum != tt.out {
-					t.Errorf("test %d.%d.%d: have %s want %s", i, j, k, sum, tt.out)
-				}
+				sum := fmt.Sprintf("%x", hsh.Sum(nil))
+				assert.Equal(t, tt.out, sum, "test %d.%d.%d: have %s want %s", i, j, k, sum, tt.out)
 			}
 
 			// Second iteration: make sure reset works.
-			h.Reset()
+			hsh.Reset()
 		}
-		PutSHA256(h)
+		PutSHA256(hsh)
 	}
 }
 
@@ -147,7 +125,7 @@ func TestAssertBlockSize(t *testing.T) {
 	t.Run("Negative", func(t *testing.T) {
 		defer func() {
 			if r := recover(); r == nil {
-				t.Error("should panic")
+				assert.Fail(t, "should panic")
 			}
 		}()
 		h := AcquireSHA256(make([]byte, 0, 1024))
