@@ -6,15 +6,18 @@ package testutil
 
 import (
 	"testing"
+
+	"github.com/stretchr/testify/assert"
 )
 
 // ShouldNotAllocate fails if f allocates.
 func ShouldNotAllocate(t *testing.T, f func()) {
+	t.Helper()
+
 	if Race {
 		t.Skip("skip while running with -race")
+
 		return
 	}
-	if a := testing.AllocsPerRun(10, f); a > 0 {
-		t.Errorf("Allocations detected: %f", a)
-	}
+	assert.Zero(t, testing.AllocsPerRun(10, f))
 }
