@@ -21,15 +21,19 @@ import (
 	"strconv"
 	"strings"
 	"testing"
+
+	"github.com/stretchr/testify/assert"
 )
 
 type attributeEncoder interface {
 	AddTo(m *Message) error
 }
 
-func addAttr(t testing.TB, m *Message, a attributeEncoder) {
+func addAttr(tb testing.TB, m *Message, a attributeEncoder) {
+	tb.Helper()
+
 	if err := a.AddTo(m); err != nil {
-		t.Error(err)
+		tb.Error(err)
 	}
 }
 
@@ -48,12 +52,9 @@ func TestMessageBuffer(t *testing.T) {
 	m.Add(AttrErrorCode, []byte{0xff, 0xfe, 0xfa})
 	m.WriteHeader()
 	mDecoded := New()
-	if _, err := mDecoded.ReadFrom(bytes.NewReader(m.Raw)); err != nil {
-		t.Error(err)
-	}
-	if !mDecoded.Equal(m) {
-		t.Error(mDecoded, "!", m)
-	}
+	_, err := mDecoded.ReadFrom(bytes.NewReader(m.Raw))
+	assert.NoError(t, err)
+	assert.True(t, mDecoded.Equal(m), "mDecoded != m")
 }
 
 func BenchmarkMessage_Write(b *testing.B) {
@@ -84,9 +85,7 @@ func TestMessageType_Value(t *testing.T) {
 	}
 	for _, tt := range tests {
 		b := tt.in.Value()
-		if b != tt.out {
-			t.Errorf("Value(%s) -> %s, want %s", tt.in, bUint16(b), bUint16(tt.out))
-		}
+		assert.Equal(t, tt.out, b, "Value(%s) -> %s, want %s", tt.in, bUint16(b), bUint16(tt.out))
 	}
 }
 
@@ -102,9 +101,7 @@ func TestMessageType_ReadValue(t *testing.T) {
 	for _, tt := range tests {
 		m := MessageType{}
 		m.ReadValue(tt.in)
-		if m != tt.out {
-			t.Errorf("ReadValue(%s) -> %s, want %s", bUint16(tt.in), m, tt.out)
-		}
+		assert.Equal(t, tt.out, m, "ReadValue(%s) -> %s, want %s", bUint16(tt.in), m, tt.out)
 	}
 }
 
@@ -119,48 +116,38 @@ func TestMessageType_ReadWriteValue(t *testing.T) {
 		m := MessageType{}
 		v := tt.Value()
 		m.ReadValue(v)
-		if m != tt {
-			t.Errorf("ReadValue(%s -> %s) = %s, should be %s", tt, bUint16(v), m, tt)
-			if m.Method != tt.Method {
-				t.Errorf("%s != %s", bUint16(uint16(m.Method)), bUint16(uint16(tt.Method)))
-			}
-		}
+		assert.Equal(t, tt, m, "ReadValue(%s -> %s) = %s, should be %s", tt, bUint16(v), m, tt)
+		assert.Equal(t, tt.Method, m.Method, "%s != %s", bUint16(uint16(m.Method)), bUint16(uint16(tt.Method)))
 	}
 }
 
 func TestMessage_WriteTo(t *testing.T) {
-	m := New()
-	m.Type = MessageType{Method: MethodBinding, Class: ClassRequest}
-	m.TransactionID = NewTransactionID()
-	m.Add(AttrErrorCode, []byte{0xff, 0xfe, 0xfa})
-	m.WriteHeader()
+	msg := New()
+	msg.Type = MessageType{Method: MethodBinding, Class: ClassRequest}
+	msg.TransactionID = NewTransactionID()
+	msg.Add(AttrErrorCode, []byte{0xff, 0xfe, 0xfa})
+	msg.WriteHeader()
 	buf := new(bytes.Buffer)
-	if _, err := m.WriteTo(buf); err != nil {
-		t.Fatal(err)
-	}
+	_, err := msg.WriteTo(buf)
+	assert.NoError(t, err)
 	mDecoded := New()
-	if _, err := mDecoded.ReadFrom(buf); err != nil {
-		t.Error(err)
-	}
-	if !mDecoded.Equal(m) {
-		t.Error(mDecoded, "!", m)
-	}
+	_, err = mDecoded.ReadFrom(buf)
+	assert.NoError(t, err)
+	assert.True(t, mDecoded.Equal(msg), "mDecoded != msg")
 }
 
 func TestMessage_Cookie(t *testing.T) {
 	buf := make([]byte, 20)
 	mDecoded := New()
-	if _, err := mDecoded.ReadFrom(bytes.NewReader(buf)); err == nil {
-		t.Error("should error")
-	}
+	_, err := mDecoded.ReadFrom(bytes.NewReader(buf))
+	assert.Error(t, err, "should error")
 }
 
 func TestMessage_LengthLessHeaderSize(t *testing.T) {
 	buf := make([]byte, 8)
 	mDecoded := New()
-	if _, err := mDecoded.ReadFrom(bytes.NewReader(buf)); err == nil {
-		t.Error("should error")
-	}
+	_, err := mDecoded.ReadFrom(bytes.NewReader(buf))
+	assert.Error(t, err, "should error")
 }
 
 func TestMessage_BadLength(t *testing.T) {
@@ -174,9 +161,8 @@ func TestMessage_BadLength(t *testing.T) {
 	m.WriteHeader()
 	m.Raw[20+3] = 10 // set attr length = 10
 	mDecoded := New()
-	if _, err := mDecoded.Write(m.Raw); err == nil {
-		t.Error("should error")
-	}
+	_, err := mDecoded.Write(m.Raw)
+	assert.Error(t, err, "should error")
 }
 
 func TestMessage_AttrLengthLessThanHeader(t *testing.T) {
@@ -195,13 +181,8 @@ func TestMessage_AttrLengthLessThanHeader(t *testing.T) {
 	binary.BigEndian.PutUint16(m.Raw[2:4], 2) // rewrite to bad length
 	_, err := mDecoded.ReadFrom(bytes.NewReader(m.Raw[:20+2]))
 	var e *DecodeErr
-	if errors.As(err, &e) {
-		if !e.IsPlace(DecodeErrPlace{"attribute", "header"}) {
-			t.Error(e, "bad place")
-		}
-	} else {
-		t.Error(err, "should be bad format")
-	}
+	assert.ErrorAs(t, err, &e)
+	assert.True(t, e.IsPlace(DecodeErrPlace{"attribute", "header"}), "bad place")
 }
 
 func TestMessage_AttrSizeLessThanLength(t *testing.T) {
@@ -224,13 +205,8 @@ func TestMessage_AttrSizeLessThanLength(t *testing.T) {
 	mDecoded := New()
 	_, err := mDecoded.ReadFrom(bytes.NewReader(m.Raw[:20+5]))
 	var e *DecodeErr
-	if errors.As(err, &e) {
-		if !e.IsPlace(DecodeErrPlace{"attribute", "value"}) {
-			t.Error(e, "bad place")
-		}
-	} else {
-		t.Error(err, "should be bad format")
-	}
+	assert.ErrorAs(t, err, &e)
+	assert.True(t, e.IsPlace(DecodeErrPlace{"attribute", "value"}), "bad place")
 }
 
 type unexpectedEOFReader struct{}
@@ -242,9 +218,7 @@ func (r unexpectedEOFReader) Read([]byte) (int, error) {
 func TestMessage_ReadFromError(t *testing.T) {
 	mDecoded := New()
 	_, err := mDecoded.ReadFrom(unexpectedEOFReader{})
-	if !errors.Is(err, io.ErrUnexpectedEOF) {
-		t.Error(err, "should be", io.ErrUnexpectedEOF)
-	}
+	assert.ErrorIs(t, err, io.ErrUnexpectedEOF, "should be", io.ErrUnexpectedEOF)
 }
 
 func BenchmarkMessageType_Value(b *testing.B) {
@@ -275,23 +249,23 @@ func BenchmarkMessage_WriteTo(b *testing.B) {
 
 func BenchmarkMessage_ReadFrom(b *testing.B) {
 	mType := MessageType{Method: MethodBinding, Class: ClassRequest}
-	m := &Message{
+	msg := &Message{
 		Type:   mType,
 		Length: 0,
 		TransactionID: [TransactionIDSize]byte{
 			1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
 		},
 	}
-	m.WriteHeader()
+	msg.WriteHeader()
 	b.ReportAllocs()
-	b.SetBytes(int64(len(m.Raw)))
-	reader := m.reader()
+	b.SetBytes(int64(len(msg.Raw)))
+	reader := msg.reader()
 	mRec := New()
 	for i := 0; i < b.N; i++ {
 		if _, err := mRec.ReadFrom(reader); err != nil {
 			b.Fatal(err)
 		}
-		reader.Reset(m.Raw)
+		reader.Reset(msg.Raw)
 		mRec.Reset()
 	}
 }
@@ -319,9 +293,7 @@ func BenchmarkMessage_ReadBytes(b *testing.B) {
 
 func TestMessageClass_String(t *testing.T) {
 	defer func() {
-		if err := recover(); err == nil {
-			t.Error(err, "should be not nil")
-		}
+		assert.NotNil(t, recover())
 	}()
 
 	v := [...]MessageClass{
@@ -331,18 +303,16 @@ func TestMessageClass_String(t *testing.T) {
 		ClassIndication,
 	}
 	for _, k := range v {
-		if k.String() == "" {
-			t.Error(k, "bad stringer")
-		}
+		assert.NotEmpty(t, k.String(), "%v bad stringer", k)
 	}
 
 	// should panic
 	p := MessageClass(0x05).String()
-	t.Error("should panic!", p)
+	assert.Fail(t, "should panic", p)
 }
 
 func TestAttrType_String(t *testing.T) {
-	v := [...]AttrType{
+	attrType := [...]AttrType{
 		AttrMappedAddress,
 		AttrUsername,
 		AttrErrorCode,
@@ -355,151 +325,97 @@ func TestAttrType_String(t *testing.T) {
 		AttrAlternateServer,
 		AttrFingerprint,
 	}
-	for _, k := range v {
-		if k.String() == "" {
-			t.Error(k, "bad stringer")
-		}
-		if strings.HasPrefix(k.String(), "0x") {
-			t.Error(k, "bad stringer")
-		}
+	for _, k := range attrType {
+		assert.NotEmpty(t, k.String(), "%v bad stringer", k)
+		assert.False(t, strings.HasPrefix(k.String(), "0x"), "%v bad stringer", k)
 	}
 	vNonStandard := AttrType(0x512)
-	if !strings.HasPrefix(vNonStandard.String(), "0x512") {
-		t.Error(vNonStandard, "bad prefix")
-	}
+	assert.True(t, strings.HasPrefix(vNonStandard.String(), "0x512"), "%v bad prefix", vNonStandard)
 }
 
 func TestMethod_String(t *testing.T) {
-	if MethodBinding.String() != "Binding" {
-		t.Error("binding is not binding!")
-	}
-	if Method(0x616).String() != "0x616" {
-		t.Error("Bad stringer", Method(0x616))
-	}
+	assert.Equal(t, "Binding", MethodBinding.String(), "binding is not binding!")
+	assert.Equal(t, "0x616", Method(0x616).String(), "Bad stringer")
 }
 
 func TestAttribute_Equal(t *testing.T) {
-	a := RawAttribute{Length: 2, Value: []byte{0x1, 0x2}}
-	b := RawAttribute{Length: 2, Value: []byte{0x1, 0x2}}
-	if !a.Equal(b) {
-		t.Error("should equal")
-	}
-	if a.Equal(RawAttribute{Type: 0x2}) {
-		t.Error("should not equal")
-	}
-	if a.Equal(RawAttribute{Length: 0x2}) {
-		t.Error("should not equal")
-	}
-	if a.Equal(RawAttribute{Length: 0x3}) {
-		t.Error("should not equal")
-	}
-	if a.Equal(RawAttribute{Length: 2, Value: []byte{0x1, 0x3}}) {
-		t.Error("should not equal")
-	}
+	attr1 := RawAttribute{Length: 2, Value: []byte{0x1, 0x2}, Type: 0x1}
+	attr2 := RawAttribute{Length: 2, Value: []byte{0x1, 0x2}, Type: 0x1}
+	assert.True(t, attr1.Equal(attr2))
+	assert.False(t, attr1.Equal(RawAttribute{Type: 0x2}))
+	assert.False(t, attr1.Equal(RawAttribute{Length: 0x2}))
+	assert.False(t, attr1.Equal(RawAttribute{Length: 0x3}))
+	assert.False(t, attr1.Equal(RawAttribute{Length: 2, Value: []byte{0x1, 0x3}}))
 }
 
-func TestMessage_Equal(t *testing.T) {
+func TestMessage_Equal(t *testing.T) { //nolint:cyclop
 	attr := RawAttribute{Length: 2, Value: []byte{0x1, 0x2}, Type: 0x1}
 	attrs := Attributes{attr}
-	a := &Message{Attributes: attrs, Length: 4 + 2}
-	b := &Message{Attributes: attrs, Length: 4 + 2}
-	if !a.Equal(b) {
-		t.Error("should equal")
-	}
-	if a.Equal(&Message{Type: MessageType{Class: 128}}) {
-		t.Error("should not equal")
-	}
+	msg1 := &Message{Attributes: attrs, Length: 4 + 2}
+	msg2 := &Message{Attributes: attrs, Length: 4 + 2}
+	assert.True(t, msg1.Equal(msg2))
+	assert.False(t, msg1.Equal(&Message{Type: MessageType{Class: 128}}))
 	tID := [TransactionIDSize]byte{
 		1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
 	}
-	if a.Equal(&Message{TransactionID: tID}) {
-		t.Error("should not equal")
-	}
-	if a.Equal(&Message{Length: 3}) {
-		t.Error("should not equal")
-	}
+	assert.False(t, msg1.Equal(&Message{TransactionID: tID}))
+	assert.False(t, msg1.Equal(&Message{Length: 3}))
 	tAttrs := Attributes{
 		{Length: 1, Value: []byte{0x1}, Type: 0x1},
 	}
-	if a.Equal(&Message{Attributes: tAttrs, Length: 4 + 2}) {
-		t.Error("should not equal")
-	}
+	assert.False(t, msg1.Equal(&Message{Attributes: tAttrs, Length: 4 + 2}))
 	tAttrs = Attributes{
 		{Length: 2, Value: []byte{0x1, 0x1}, Type: 0x2},
 	}
-	if a.Equal(&Message{Attributes: tAttrs, Length: 4 + 2}) {
-		t.Error("should not equal")
-	}
-	if !(*Message)(nil).Equal(nil) {
-		t.Error("nil should be equal to nil")
-	}
-	if a.Equal(nil) {
-		t.Error("non-nil should not be equal to nil")
-	}
+	assert.False(t, msg1.Equal(&Message{Attributes: tAttrs, Length: 4 + 2}))
+	assert.True(t, (*Message)(nil).Equal(nil), "nil should be equal to nil")
+	assert.False(t, msg1.Equal(nil), "non-nil should not be equal to nil")
 	t.Run("Nil attributes", func(t *testing.T) {
-		a := &Message{
+		msg1 := &Message{
 			Attributes: nil,
 			Length:     4 + 2,
 		}
-		b := &Message{
+		msg2 := &Message{
 			Attributes: attrs,
 			Length:     4 + 2,
 		}
-		if a.Equal(b) {
-			t.Error("should not equal")
-		}
-		if b.Equal(a) {
-			t.Error("should not equal")
-		}
-		b.Attributes = nil
-		if !a.Equal(b) {
-			t.Error("should equal")
-		}
+		assert.False(t, msg1.Equal(msg2))
+		assert.False(t, msg2.Equal(msg1))
+		msg2.Attributes = nil
+		assert.True(t, msg1.Equal(msg2))
 	})
 	t.Run("Attributes length", func(t *testing.T) {
 		attr := RawAttribute{Length: 2, Value: []byte{0x1, 0x2}, Type: 0x1}
 		attr1 := RawAttribute{Length: 2, Value: []byte{0x1, 0x2}, Type: 0x1}
 		a := &Message{Attributes: Attributes{attr}, Length: 4 + 2}
 		b := &Message{Attributes: Attributes{attr, attr1}, Length: 4 + 2}
-		if a.Equal(b) {
-			t.Error("should not equal")
-		}
+		assert.False(t, a.Equal(b))
 	})
 	t.Run("Attributes values", func(t *testing.T) {
 		attr := RawAttribute{Length: 2, Value: []byte{0x1, 0x2}, Type: 0x1}
 		attr1 := RawAttribute{Length: 2, Value: []byte{0x1, 0x1}, Type: 0x1}
 		a := &Message{Attributes: Attributes{attr, attr}, Length: 4 + 2}
 		b := &Message{Attributes: Attributes{attr, attr1}, Length: 4 + 2}
-		if a.Equal(b) {
-			t.Error("should not equal")
-		}
+		assert.False(t, a.Equal(b))
 	})
 }
 
 func TestMessageGrow(t *testing.T) {
 	m := New()
 	m.grow(512)
-	if len(m.Raw) < 512 {
-		t.Error("Bad length", len(m.Raw))
-	}
+	assert.GreaterOrEqual(t, len(m.Raw), 512)
 }
 
 func TestMessageGrowSmaller(t *testing.T) {
 	m := New()
 	m.grow(2)
-	if cap(m.Raw) < 20 {
-		t.Error("Bad capacity", cap(m.Raw))
-	}
-	if len(m.Raw) < 20 {
-		t.Error("Bad length", len(m.Raw))
-	}
+	assert.GreaterOrEqual(t, cap(m.Raw), 20)
+	assert.GreaterOrEqual(t, len(m.Raw), 20)
 }
 
 func TestMessage_String(t *testing.T) {
 	m := New()
-	if m.String() == "" {
-		t.Error("bad string")
-	}
+	assert.NotEmpty(t, m.String())
 }
 
 func TestIsMessage(t *testing.T) {
@@ -523,9 +439,7 @@ func TestIsMessage(t *testing.T) {
 		}, true}, // 6
 	}
 	for i, v := range tt {
-		if got := IsMessage(v.in); got != v.out {
-			t.Errorf("tt[%d]: IsMessage(%+v) %v != %v", i, v.in, got, v.out)
-		}
+		assert.Equal(t, v.out, IsMessage(v.in), "tt[%d]: IsMessage(%+v)", i, v.in)
 	}
 }
 
@@ -547,20 +461,17 @@ func BenchmarkIsMessage(b *testing.B) {
 }
 
 func loadData(tb testing.TB, name string) []byte {
+	tb.Helper()
+
 	name = filepath.Join("testdata", name)
 	f, err := os.Open(name) //nolint:gosec
-	if err != nil {
-		tb.Fatal(err)
-	}
+	assert.NoError(tb, err)
 	defer func() {
-		if errClose := f.Close(); errClose != nil {
-			tb.Fatal(errClose)
-		}
+		assert.NoError(tb, f.Close())
 	}()
 	v, err := io.ReadAll(f)
-	if err != nil {
-		tb.Fatal(err)
-	}
+	assert.NoError(tb, err)
+
 	return v
 }
 
@@ -568,9 +479,7 @@ func TestExampleChrome(t *testing.T) {
 	buf := loadData(t, "ex1_chrome.stun")
 	m := New()
 	_, err := m.Write(buf)
-	if err != nil {
-		t.Errorf("Failed to parse ex1_chrome: %s", err)
-	}
+	assert.NoError(t, err, "Failed to parse ex1_chrome")
 }
 
 func TestMessageFromBrowsers(t *testing.T) {
@@ -578,34 +487,23 @@ func TestMessageFromBrowsers(t *testing.T) {
 	reader := csv.NewReader(bytes.NewReader(loadData(t, "frombrowsers.csv")))
 	reader.Comment = '#'
 	_, err := reader.Read() // skipping header
-	if err != nil {
-		t.Fatal("failed to skip header of csv: ", err)
-	}
+	assert.NoError(t, err, "failed to skip header of csv")
 	crcTable := crc64.MakeTable(crc64.ISO)
-	m := New()
+	msg := New()
 	for {
 		line, err := reader.Read()
 		if errors.Is(err, io.EOF) {
 			break
 		}
-		if err != nil {
-			t.Fatal("failed to read csv line: ", err)
-		}
+		assert.NoError(t, err, "failed to read csv line")
 		data, err := base64.StdEncoding.DecodeString(line[1])
-		if err != nil {
-			t.Fatal("failed to decode ", line[1], " as base64: ", err)
-		}
+		assert.NoError(t, err)
 		b, err := strconv.ParseUint(line[2], 10, 64)
-		if err != nil {
-			t.Fatal(err)
-		}
-		if b != crc64.Checksum(data, crcTable) {
-			t.Error("crc64 check failed for ", line[1])
-		}
-		if _, err = m.Write(data); err != nil {
-			t.Error("failed to decode ", line[1], " as message: ", err)
-		}
-		m.Reset()
+		assert.NoError(t, err)
+		assert.Equal(t, b, crc64.Checksum(data, crcTable), "crc64 check failed for %s", line[1])
+		_, err = msg.Write(data)
+		assert.NoError(t, err, "failed to decode %s as message: %s", line[1], err)
+		msg.Reset()
 	}
 }
 
@@ -614,50 +512,40 @@ func BenchmarkMessage_NewTransactionID(b *testing.B) {
 	m := new(Message)
 	m.WriteHeader()
 	for i := 0; i < b.N; i++ {
-		if err := m.NewTransactionID(); err != nil {
-			b.Fatal(err)
-		}
+		assert.NoError(b, m.NewTransactionID())
 	}
 }
 
 func BenchmarkMessageFull(b *testing.B) {
 	b.ReportAllocs()
-	m := new(Message)
+	msg := new(Message)
 	s := NewSoftware("software")
 	addr := &XORMappedAddress{
 		IP: net.IPv4(213, 1, 223, 5),
 	}
 	for i := 0; i < b.N; i++ {
-		if err := addr.AddTo(m); err != nil {
-			b.Fatal(err)
-		}
-		if err := s.AddTo(m); err != nil {
-			b.Fatal(err)
-		}
-		m.WriteAttributes()
-		m.WriteHeader()
-		Fingerprint.AddTo(m) //nolint:errcheck,gosec
-		m.WriteHeader()
-		m.Reset()
+		assert.NoError(b, addr.AddTo(msg))
+		assert.NoError(b, s.AddTo(msg))
+		msg.WriteAttributes()
+		msg.WriteHeader()
+		Fingerprint.AddTo(msg) //nolint:errcheck,gosec
+		msg.WriteHeader()
+		msg.Reset()
 	}
 }
 
 func BenchmarkMessageFullHardcore(b *testing.B) {
 	b.ReportAllocs()
-	m := new(Message)
+	msg := new(Message)
 	s := NewSoftware("software")
 	addr := &XORMappedAddress{
 		IP: net.IPv4(213, 1, 223, 5),
 	}
 	for i := 0; i < b.N; i++ {
-		if err := addr.AddTo(m); err != nil {
-			b.Fatal(err)
-		}
-		if err := s.AddTo(m); err != nil {
-			b.Fatal(err)
-		}
-		m.WriteHeader()
-		m.Reset()
+		assert.NoError(b, addr.AddTo(msg))
+		assert.NoError(b, s.AddTo(msg))
+		msg.WriteHeader()
+		msg.Reset()
 	}
 }
 
@@ -679,18 +567,14 @@ func BenchmarkMessage_WriteHeader(b *testing.B) {
 func TestMessage_Contains(t *testing.T) {
 	m := new(Message)
 	m.Add(AttrSoftware, []byte("value"))
-	if !m.Contains(AttrSoftware) {
-		t.Error("message should contain software")
-	}
-	if m.Contains(AttrNonce) {
-		t.Error("message should not contain nonce")
-	}
+	assert.True(t, m.Contains(AttrSoftware), "message should contain software")
+	assert.False(t, m.Contains(AttrNonce), "message should not contain nonce")
 }
 
 func ExampleMessage() {
 	buf := new(bytes.Buffer)
-	m := new(Message)
-	m.Build(BindingRequest, //nolint:errcheck,gosec
+	msg := new(Message)
+	msg.Build(BindingRequest, //nolint:errcheck,gosec
 		NewTransactionIDSetter([TransactionIDSize]byte{
 			1, 2, 3, 4, 5, 6, 7, 8, 9, 0, 1,
 		}),
@@ -707,8 +591,8 @@ func ExampleMessage() {
 	//	m.Build(&software) // no allocations
 	// If you pass software as value, there will be 1 allocation.
 	// This rule is correct for all setters.
-	fmt.Println(m, "buff length:", len(m.Raw))
-	n, err := m.WriteTo(buf)
+	fmt.Println(msg, "buff length:", len(msg.Raw))
+	n, err := msg.WriteTo(buf)
 	fmt.Println("wrote", n, "err", err)
 
 	// Decoding from buf new *Message.
@@ -743,6 +627,7 @@ func ExampleMessage() {
 		fmt.Println("fingerprint: failed")
 	}
 
+	//nolint:lll
 	// Output:
 	// Binding request l=48 attrs=3 id=AQIDBAUGBwgJAAEA, attr0=SOFTWARE attr1=MESSAGE-INTEGRITY attr2=FINGERPRINT  buff length: 68
 	// wrote 68 err <nil>
@@ -781,13 +666,9 @@ func TestAllocations(t *testing.T) {
 		allocs := testing.AllocsPerRun(10, func() {
 			m.Reset()
 			m.WriteHeader()
-			if err := s.AddTo(m); err != nil {
-				t.Errorf("[%d] failed to add", i)
-			}
+			assert.NoError(t, s.AddTo(m), "[%d] failed to add", i)
 		})
-		if allocs > 0 {
-			t.Errorf("[%d] allocated %.0f", i, allocs)
-		}
+		assert.Zero(t, allocs, "[%d] allocated", i)
 	}
 }
 
@@ -811,10 +692,8 @@ func TestAllocationsGetters(t *testing.T) {
 		NewShortTermIntegrity("pwd"),
 		Fingerprint,
 	}
-	m := New()
-	if err := m.Build(setters...); err != nil {
-		t.Error("failed to build", err)
-	}
+	msg := New()
+	assert.NoError(t, msg.Build(setters...))
 	getters := []Getter{
 		new(Nonce),
 		new(Username),
@@ -826,72 +705,54 @@ func TestAllocationsGetters(t *testing.T) {
 		g := g
 		i := i
 		allocs := testing.AllocsPerRun(10, func() {
-			if err := g.GetFrom(m); err != nil {
-				t.Errorf("[%d] failed to get", i)
-			}
+			assert.NoError(t, g.GetFrom(msg), "[%d] failed to get", i)
 		})
-		if allocs > 0 {
-			t.Errorf("[%d] allocated %.0f", i, allocs)
-		}
+		assert.Zero(t, allocs, "[%d] allocated", i)
 	}
 }
 
 func TestMessageFullSize(t *testing.T) {
-	m := new(Message)
-	if err := m.Build(BindingRequest,
+	msg := new(Message)
+	assert.NoError(t, msg.Build(BindingRequest,
 		NewTransactionIDSetter([TransactionIDSize]byte{
 			1, 2, 3, 4, 5, 6, 7, 8, 9, 0, 1,
 		}),
 		NewSoftware("pion/stun"),
 		NewLongTermIntegrity("username", "realm", "password"),
 		Fingerprint,
-	); err != nil {
-		t.Fatal(err)
-	}
-	m.Raw = m.Raw[:len(m.Raw)-10]
+	))
+	msg.Raw = msg.Raw[:len(msg.Raw)-10]
 
 	decoder := new(Message)
-	decoder.Raw = m.Raw[:len(m.Raw)-10]
-	if err := decoder.Decode(); err == nil {
-		t.Error("decode on truncated buffer should error")
-	}
+	decoder.Raw = msg.Raw[:len(msg.Raw)-10]
+	assert.Error(t, decoder.Decode(), "decode on truncated buffer should error")
 }
 
 func TestMessage_CloneTo(t *testing.T) {
-	m := new(Message)
-	if err := m.Build(BindingRequest,
+	msg := new(Message)
+	assert.NoError(t, msg.Build(BindingRequest,
 		NewTransactionIDSetter([TransactionIDSize]byte{
 			1, 2, 3, 4, 5, 6, 7, 8, 9, 0, 1,
 		}),
 		NewSoftware("pion/stun"),
 		NewLongTermIntegrity("username", "realm", "password"),
 		Fingerprint,
-	); err != nil {
-		t.Fatal(err)
-	}
-	m.Encode()
-	b := new(Message)
-	if err := m.CloneTo(b); err != nil {
-		t.Fatal(err)
-	}
-	if !b.Equal(m) {
-		t.Fatal("not equal")
-	}
+	))
+	msg.Encode()
+	msg2 := new(Message)
+	assert.NoError(t, msg.CloneTo(msg2))
+	assert.True(t, msg2.Equal(msg), "cloned message should equal original")
 	// Corrupting m and checking that b is not corrupted.
-	s, ok := b.Attributes.Get(AttrSoftware)
-	if !ok {
-		t.Fatal("no software attribute")
-	}
+	s, ok := msg2.Attributes.Get(AttrSoftware)
+	assert.True(t, ok)
 	s.Value[0] = 'k'
-	if b.Equal(m) {
-		t.Fatal("should not be equal")
-	}
+	assert.False(t, msg2.Equal(msg), "should not be equal")
 }
 
 func BenchmarkMessage_CloneTo(b *testing.B) {
 	b.ReportAllocs()
-	m := new(Message)
-	if err := m.Build(BindingRequest,
+	msg := new(Message)
+	if err := msg.Build(BindingRequest,
 		NewTransactionIDSetter([TransactionIDSize]byte{
 			1, 2, 3, 4, 5, 6, 7, 8, 9, 0, 1,
 		}),
@@ -901,41 +762,33 @@ func BenchmarkMessage_CloneTo(b *testing.B) {
 	); err != nil {
 		b.Fatal(err)
 	}
-	b.SetBytes(int64(len(m.Raw)))
+	b.SetBytes(int64(len(msg.Raw)))
 	a := new(Message)
-	m.CloneTo(a) //nolint:errcheck,gosec
+	msg.CloneTo(a) //nolint:errcheck,gosec
 	for i := 0; i < b.N; i++ {
-		if err := m.CloneTo(a); err != nil {
+		if err := msg.CloneTo(a); err != nil {
 			b.Fatal(err)
 		}
 	}
 }
 
 func TestMessage_AddTo(t *testing.T) {
-	m := new(Message)
-	if err := m.Build(BindingRequest,
+	msg := new(Message)
+	assert.NoError(t, msg.Build(BindingRequest,
 		NewTransactionIDSetter([TransactionIDSize]byte{
 			1, 2, 3, 4, 5, 6, 7, 8, 9, 0, 1,
 		}),
 		Fingerprint,
-	); err != nil {
-		t.Fatal(err)
-	}
-	m.Encode()
+	))
+	msg.Encode()
 	b := new(Message)
-	if err := m.CloneTo(b); err != nil {
-		t.Fatal(err)
-	}
-	m.TransactionID = [TransactionIDSize]byte{
+	assert.NoError(t, msg.CloneTo(b))
+	msg.TransactionID = [TransactionIDSize]byte{
 		1, 2, 3, 4, 5, 6, 7, 8, 9, 0, 2,
 	}
-	if b.Equal(m) {
-		t.Fatal("should not be equal")
-	}
-	m.AddTo(b) //nolint:errcheck,gosec
-	if !b.Equal(m) {
-		t.Fatal("should be equal")
-	}
+	assert.False(t, b.Equal(msg), "should not be equal")
+	msg.AddTo(b) //nolint:errcheck,gosec
+	assert.True(t, b.Equal(msg), "should be equal")
 }
 
 func BenchmarkMessage_AddTo(b *testing.B) {
@@ -960,32 +813,22 @@ func BenchmarkMessage_AddTo(b *testing.B) {
 
 func TestDecode(t *testing.T) {
 	t.Run("Nil", func(t *testing.T) {
-		if err := Decode(nil, nil); !errors.Is(err, ErrDecodeToNil) {
-			t.Errorf("unexpected error: %v", err)
-		}
+		assert.ErrorIs(t, Decode(nil, nil), ErrDecodeToNil)
 	})
-	m := New()
-	m.Type = MessageType{Method: MethodBinding, Class: ClassRequest}
-	m.TransactionID = NewTransactionID()
-	m.Add(AttrErrorCode, []byte{0xff, 0xfe, 0xfa})
-	m.WriteHeader()
+	msg := New()
+	msg.Type = MessageType{Method: MethodBinding, Class: ClassRequest}
+	msg.TransactionID = NewTransactionID()
+	msg.Add(AttrErrorCode, []byte{0xff, 0xfe, 0xfa})
+	msg.WriteHeader()
 	mDecoded := New()
-	if err := Decode(m.Raw, mDecoded); err != nil {
-		t.Errorf("unexpected error: %v", err)
-	}
-	if !mDecoded.Equal(m) {
-		t.Error("decoded result is not equal to encoded message")
-	}
+	assert.NoError(t, Decode(msg.Raw, mDecoded))
+	assert.True(t, mDecoded.Equal(msg), "decoded result is not equal to encoded message")
 	t.Run("ZeroAlloc", func(t *testing.T) {
 		allocs := testing.AllocsPerRun(10, func() {
 			mDecoded.Reset()
-			if err := Decode(m.Raw, mDecoded); err != nil {
-				t.Error(err)
-			}
+			assert.NoError(t, Decode(msg.Raw, mDecoded))
 		})
-		if allocs > 0 {
-			t.Error("unexpected allocations")
-		}
+		assert.Zero(t, allocs, "unexpected allocations")
 	})
 }
 
@@ -1008,59 +851,47 @@ func BenchmarkDecode(b *testing.B) {
 }
 
 func TestMessage_MarshalBinary(t *testing.T) {
-	m := MustBuild(
+	msg := MustBuild(
 		NewSoftware("software"),
 		&XORMappedAddress{
 			IP: net.IPv4(213, 1, 223, 5),
 		},
 	)
-	data, err := m.MarshalBinary()
-	if err != nil {
-		t.Fatal(err)
-	}
+	data, err := msg.MarshalBinary()
+	assert.NoError(t, err)
 
 	// Reset m.Raw to check retention.
-	for i := range m.Raw {
-		m.Raw[i] = 0
-	}
-	if err := m.UnmarshalBinary(data); err != nil {
-		t.Fatal(err)
+	for i := range msg.Raw {
+		msg.Raw[i] = 0
 	}
+	assert.NoError(t, msg.UnmarshalBinary(data))
 
 	// Reset data to check retention.
 	for i := range data {
 		data[i] = 0
 	}
-	if err := m.Decode(); err != nil {
-		t.Fatal(err)
-	}
+	assert.NoError(t, msg.Decode())
 }
 
 func TestMessage_GobDecode(t *testing.T) {
-	m := MustBuild(
+	msg := MustBuild(
 		NewSoftware("software"),
 		&XORMappedAddress{
 			IP: net.IPv4(213, 1, 223, 5),
 		},
 	)
-	data, err := m.GobEncode()
-	if err != nil {
-		t.Fatal(err)
-	}
+	data, err := msg.GobEncode()
+	assert.NoError(t, err)
 
 	// Reset m.Raw to check retention.
-	for i := range m.Raw {
-		m.Raw[i] = 0
-	}
-	if err := m.GobDecode(data); err != nil {
-		t.Fatal(err)
+	for i := range msg.Raw {
+		msg.Raw[i] = 0
 	}
+	assert.NoError(t, msg.GobDecode(data))
 
 	// Reset data to check retention.
 	for i := range data {
 		data[i] = 0
 	}
-	if err := m.Decode(); err != nil {
-		t.Fatal(err)
-	}
+	assert.NoError(t, msg.Decode())
 }
