@@ -5,47 +5,35 @@ package stun
 
 import (
 	"testing"
+
+	"github.com/stretchr/testify/assert"
 )
 
 func TestUnknownAttributes(t *testing.T) {
-	m := new(Message)
-	a := &UnknownAttributes{
+	msg := new(Message)
+	attr := &UnknownAttributes{
 		AttrDontFragment,
 		AttrChannelNumber,
 	}
-	if a.String() != "DONT-FRAGMENT, CHANNEL-NUMBER" {
-		t.Error("bad String:", a)
-	}
-	if (UnknownAttributes{}).String() != "<nil>" {
-		t.Error("bad blank string")
-	}
-	if err := a.AddTo(m); err != nil {
-		t.Error(err)
-	}
+	assert.Equal(t, "DONT-FRAGMENT, CHANNEL-NUMBER", attr.String())
+	assert.Equal(t, "<nil>", (UnknownAttributes{}).String())
+	assert.NoError(t, attr.AddTo(msg))
 	t.Run("GetFrom", func(t *testing.T) {
 		attrs := make(UnknownAttributes, 10)
-		if err := attrs.GetFrom(m); err != nil {
-			t.Error(err)
-		}
-		for i, at := range *a {
-			if at != attrs[i] {
-				t.Error("expected", at, "!=", attrs[i])
-			}
+		assert.NoError(t, attrs.GetFrom(msg))
+		for i, at := range *attr {
+			assert.Equal(t, at, attrs[i])
 		}
 		mBlank := new(Message)
-		if err := attrs.GetFrom(mBlank); err == nil {
-			t.Error("should error")
-		}
+		assert.Error(t, attrs.GetFrom(mBlank))
 		mBlank.Add(AttrUnknownAttributes, []byte{1, 2, 3})
-		if err := attrs.GetFrom(mBlank); err == nil {
-			t.Error("should error")
-		}
+		assert.Error(t, attrs.GetFrom(mBlank))
 	})
 }
 
 func BenchmarkUnknownAttributes(b *testing.B) {
-	m := new(Message)
-	a := UnknownAttributes{
+	msg := new(Message)
+	attr := UnknownAttributes{
 		AttrDontFragment,
 		AttrChannelNumber,
 		AttrRealm,
@@ -54,20 +42,20 @@ func BenchmarkUnknownAttributes(b *testing.B) {
 	b.Run("AddTo", func(b *testing.B) {
 		b.ReportAllocs()
 		for i := 0; i < b.N; i++ {
-			if err := a.AddTo(m); err != nil {
+			if err := attr.AddTo(msg); err != nil {
 				b.Fatal(err)
 			}
-			m.Reset()
+			msg.Reset()
 		}
 	})
 	b.Run("GetFrom", func(b *testing.B) {
 		b.ReportAllocs()
-		if err := a.AddTo(m); err != nil {
+		if err := attr.AddTo(msg); err != nil {
 			b.Fatal(err)
 		}
 		attrs := make(UnknownAttributes, 0, 10)
 		for i := 0; i < b.N; i++ {
-			if err := attrs.GetFrom(m); err != nil {
+			if err := attrs.GetFrom(msg); err != nil {
 				b.Fatal(err)
 			}
 			attrs = attrs[:0]
